@@ -143,36 +143,84 @@ def add_new_animes_command(db_uri: str, random_sleep: bool) -> None:
 @db_command_group.command(name="add-animes-detail")
 @click.argument("db-uri")
 @click.option("--only-new-anime/--no-only-new-anime", is_flag=True, default=True)
-@click.option(
-    "--random-sleep",
-    is_flag=True,
-    default=False,
-)
+@click.option("--only-old-anime/--no-only-old-anime", is_flag=True, default=False)
+@click.option("--random-sleep", is_flag=True, default=False)
+@click.option("--retry-limit", default=3, type=int)
 def add_animes_detail_command(
-    db_uri: str, only_new_anime: bool, random_sleep: bool
+    db_uri: str,
+    only_new_anime: bool,
+    only_old_anime: bool,
+    random_sleep: bool,
+    retry_limit: int,
 ) -> None:
     """Parse anime data from first episode and add data to database"""
 
+    if only_new_anime and only_old_anime:
+        click.echo(
+            click.style(
+                "Error: only_new_anime {only_new_anime} and "
+                "only_old_anime {only_old_anime} are mutually exclusive"
+            )
+        )
+        return
+
     engine = sqlalchemy.create_engine(db_uri)
     with Session(engine) as session, session.begin():
         stmt = select(models.Anime.sn).where(models.Anime.is_available.isnot(False))
+
         if only_new_anime:
             stmt = stmt.where(models.Anime.is_new.is_(True))
+        elif only_old_anime:
+            stmt = stmt.where(models.Anime.is_new.is_(False))
+
         animes_sn = session.execute(stmt).scalars().all()
         click.echo(f"Adding detail data for {len(animes_sn)} animes to {db_uri}")
 
         with click.progressbar(animes_sn) as animes_bar:
             for anime_sn in animes_bar:
-                try:
-                    anime = parser.get_anime_detail_data(anime_sn)
-                except Exception as e:
-                    click.echo(f"Failed to parser anime {anime_sn} due to {str(e)}")
+                stmt = select(models.Anime).where(models.Anime.sn == anime_sn)
+                anime_obj = session.execute(stmt).fetchone()[0]  # type: ignore
+
+                click.echo(f"\nParsing anime '{anime_obj.name}' ({anime_sn})")
+
+                retry_count = 0
+                while retry_count <= retry_limit:
+                    try:
+                        anime = parser.get_anime_detail_data(anime_sn)
+                        break
+                    except AttributeError as e:
+                        click.echo(
+                            click.style(
+                                f"Failed to parser {anime_obj.name} ({anime_sn}) due to {str(e)} "
+                                "(most likely due to parsing too frequently)",
+                                fg="red",
+                            )
+                        )
+                        if "'NoneType' object has no attribute 'text'" == str(e):
+                            sec = randint(0, 10)
+                            click.echo(f"\nSleep for {sec} seconds")
+                            sleep(sec)
+                        retry_count += 1
+                        click.echo(
+                            click.style(f"{retry_count} time retry", fg="yellow")
+                        )
+                    except Exception as e:
+                        click.echo(
+                            click.style(
+                                f"Failed to parser {anime_obj.name} ({anime_sn}) due to {str(e)} "
+                                "(most likely due to parsing too frequently)",
+                                fg="red",
+                            )
+                        )
 
                 if not anime:
-                    stmt = select(models.Anime).where(models.Anime.sn == anime_sn)
-                    anime_obj = session.execute(stmt).fetchone()[0]  # type: ignore
                     anime_obj.is_available = False
-                    click.echo(f"\nanime {anime_sn} is unaviable for now")
+                    click.echo(
+                        click.style(
+                            f"\nanime '{anime_obj.name}' ({anime_sn}) is unaviable for now",
+                            fg="yellow",
+                        )
+                    )
                     continue
 
                 if is_score_or_reviewer_changed_since_latest_update(
@@ -206,4 +254,5 @@ def add_animes_detail_command(
                     sec = randint(0, 10)
                     click.echo(f"\nSleep for {sec} seconds")
                     sleep(sec)
+
     click.echo("Finish adding anime details")
